==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/regions/sw_KE.php <==
<?php

return [
    'Names' => [
        'AF' => 'Afghanistani',
        'AI' => 'Anguila',
        'AQ' => 'Antaktika',
        'AZ' => 'Azabajani',
        'BJ' => 'Benini',
        'BT' => 'Bhutani',
        'BY' => 'Belarusi',
        'CC' => 'Visiwa vya Kokos (Keeling)',
        'CD' => 'Kongo - Kinshasa',
        'CV' => 'Kepuvede',
        'EC' => 'Ekwado',
        'GA' => 'Gaboni',
        'GL' => 'Grinilandi',
        'GP' => 'Gwadelupe',
        'GS' => 'Visiwa vya Jojia ya Kusini na Sandwich ya Kusini',
        'GU' => 'Guami',
        'HR' => 'Kroashia',
        'IO' => 'Himaya ya Uingereza katika Bahari Hindi',
        'JO' => 'Yordani',
        'KY' => 'Visiwa vya Kaimani',
        'LA' => 'Laosi',
        'LB' => 'Lebanoni',
        'LI' => 'Lishenteni',
        'LS' => 'Lesotho',
        'LU' => 'Lasembagi',
        'LV' => 'Lativia',
        'MA' => 'Moroko',
        'MC' => 'Monako',
        'MK' => 'Masedonia',
        'MM' => 'Myama (Burma)',
        'MQ' => 'Martiniki',
        'MS' => 'Montserati',
        'NC' => 'Nyukaledonia',
        'NE' => 'Nijeri',
        'NO' => 'Norwe',
        'NP' => 'Nepali',
        'OM' => 'Omani',
        'PF' => 'Polinesia ya Ufaransa',
        'PG' => 'Papua Guinea Mpya',
        'PL' => 'Polandi',
        'PR' => 'Puetoriko',
        'PS' => 'Himaya za Palestina',
        'PY' => 'Paragwai',
        'QA' => 'Katari',
        'SG' => 'Singapuri',
        'SR' => 'Surinamu',
        'ST' => 'Sao Tome na Prinsipe',
        'SY' => 'Shamu',
        'TD' => 'Chadi',
        'TH' => 'Thailandi',
        'TM' => 'Turukimenstani',
        'TW' => 'Taiwani',
        'UA' => 'Ukreni',
        'UY' => 'Urugwai',
        'VA' => 'Mji wa Vatikani',
        'VG' => 'Visiwa vya Virgin vya Uingereza',
        'VI' => 'Visiwa vya Virgin vya Marekani',
        'YT' => 'Mayote',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/regions/sw_KE.php <==
<?php

return [
    'Names' => [
        'AF' => 'Afghanistani',
        'AG' => 'Antigua na Babuda',
        'AI' => 'Anguila',
        'AQ' => 'Antaktika',
        'AZ' => 'Azabajani',
        'BB' => 'Babados',
        'BJ' => 'Benini',
        'BS' => 'Bahamas',
        'BT' => 'Bhutani',
        'BY' => 'Belarusi',
        'CC' => 'Visiwa vya Kokos (Keeling)',
        'CD' => 'Kongo - Kinshasa',
        'CV' => 'Kepuvede',
        'CW' => 'Kurakao',
        'EC' => 'Ekwado',
        'GA' => 'Gaboni',
        'GP' => 'Gwadelupe',
        'GS' => 'Visiwa vya Jojia Kusini na Sandwich Kusini',
        'GT' => 'Gwatemala',
        'GU' => 'Guami',
        'HR' => 'Kroashia',
        'IO' => 'Himaya ya Uingereza katika Bahari Hindi',
        'JO' => 'Yordani',
        'LA' => 'Laosi',
        'LB' => 'Lebanoni',
        'LI' => 'Lishenteni',
        'LS' => 'Lesotho',
        'LU' => 'Lasembagi',
        'LV' => 'Lativia',
        'MA' => 'Moroko',
        'MC' => 'Monako',
        'MK' => 'Masedonia',
        'MM' => 'Myama (Burma)',
        'MS' => 'Montserati',
        'NC' => 'Nyukaledonia',
        'NE' => 'Nijeri',
        'NO' => 'Norwe',
        'NP' => 'Nepali',
        'OM' => 'Omani',
        'PF' => 'Polinesia ya Ufaransa',
        'PG' => 'Papua Guinea Mpya',
        'PL' => 'Polandi',
        'PM' => 'St. Pierre na Miquelon',
        'PR' => 'Pwetoriko',
        'PS' => 'Himaya za Palestina',
        'PY' => 'Paragwai',
        'QA' => 'Katari',
        'SG' => 'Singapuri',
        'ST' => 'Sao Tome na Prinsipe',
        'SV' => 'Elsalvado',
        'SY' => 'Shamu',
        'TD' => 'Chadi',
        'TH' => 'Thailandi',
        'TM' => 'Turukimenstani',
        'TW' => 'Taiwani',
        'UA' => 'Ukreni',
        'UY' => 'Urugwai',
        'VA' => 'Mji wa Vatikani',
        'VG' => 'Visiwa vya Virgin vya Uingereza',
        'VI' => 'Visiwa vya Virgin vya Marekani',
        'YT' => 'Mayote',
    ],
];
